GithubSignInButton class

GitHub sign-in button

Branded button for GitHub OAuth authentication.

GithubSignInButton(
  onPressed: () => context.signInWithGitHub(),
)
Inheritance

Constructors

GithubSignInButton({void onPressed()?, String label = 'Continue with GitHub', ButtonSize size = ButtonSize.medium, bool fullWidth = false, bool disabled = false, bool loading = false, Key? key})
const

Properties

disabled bool
Whether the button is disabled
final
fullWidth bool
Whether to expand to full width
final
hashCode int
The hash code for this object.
no setterinherited
key Key?
Controls how one component replaces another component in the tree.
finalinherited
label String
Button label
final
loading bool
Whether the button is loading
final
onPressed → void Function()?
Click handler (optional - defaults to context.signInWithGitHub())
final
runtimeType Type
A representation of the runtime type of the object.
no setterinherited
size ButtonSize
Button size
final

Methods

build(BuildContext context) Component
Describes the part of the user interface represented by this component.
override
createElement() Element
Creates a StatelessElement to manage this component's location in the tree.
inherited
noSuchMethod(Invocation invocation) → dynamic
Invoked when a nonexistent method or property is accessed.
inherited
shouldRebuild(covariant Component newComponent) bool
Implement this method to determine whether a rebuild can be skipped.
inherited
toString() String
A string representation of this object.
inherited

Operators

operator ==(Object other) bool
The equality operator.
inherited