ArcaneForgotPasswordCard class

Forgot password card component

Provides a password reset UI with email input.

ArcaneForgotPasswordCard(
  loginRoute: '/login',
  header: Logo(),
)
Inheritance

Constructors

ArcaneForgotPasswordCard({Component? header, String? loginRoute, void onSuccess()?, String maxWidth = '400px', Key? key})
const

Properties

hashCode int
The hash code for this object.
no setterinherited
Header component (logo, title, etc.)
final
key Key?
Controls how one component replaces another component in the tree.
finalinherited
loginRoute String?
Route for login link
final
maxWidth String
Max width of the card
final
onSuccess → void Function()?
Callback when email is sent successfully
final
runtimeType Type
A representation of the runtime type of the object.
no setterinherited

Methods

createElement() Element
Creates a StatefulElement to manage this component's location in the tree.
inherited
createState() State<ArcaneForgotPasswordCard>
Creates the mutable state for this component at a given location in the tree.
override
noSuchMethod(Invocation invocation) → dynamic
Invoked when a nonexistent method or property is accessed.
inherited
toString() String
A string representation of this object.
inherited

Operators

operator ==(Object other) bool
The equality operator.
inherited