SocialSignInButton class
Base social sign-in button
Provides consistent styling for OAuth provider buttons.
- Inheritance
-
- Object
- Component
- StatelessComponent
- SocialSignInButton
Constructors
- SocialSignInButton({required String label, Component? icon, void onPressed()?, ButtonSize size = ButtonSize.medium, bool disabled = false, bool loading = false, bool fullWidth = false, String? backgroundColor, String? foregroundColor, String? borderColor, String? hoverBackgroundColor, Key? key})
-
const
Properties
- backgroundColor → String?
-
Background color (optional, defaults to outline style)
final
- borderColor → String?
-
Border color (optional)
final
- disabled → bool
-
Whether the button is disabled
final
- foregroundColor → String?
-
Text/icon color (optional)
final
- fullWidth → bool
-
Whether to expand to full width
final
- hashCode → int
-
The hash code for this object.
no setterinherited
- hoverBackgroundColor → String?
-
Hover background color (optional)
final
- icon → Component?
-
Icon component (SVG or emoji)
final
- key → Key?
-
Controls how one component replaces another component in the tree.
finalinherited
- label → String
-
Button label text
final
- loading → bool
-
Whether the button is loading
final
- onPressed → void Function()?
-
Click handler
final
- runtimeType → Type
-
A representation of the runtime type of the object.
no setterinherited
- size → ButtonSize
-
Button size
final
Methods
-
build(
BuildContext context) → Component -
Describes the part of the user interface represented by this component.
override
-
createElement(
) → Element -
Creates a StatelessElement to manage this component's location in the tree.
inherited
-
noSuchMethod(
Invocation invocation) → dynamic -
Invoked when a nonexistent method or property is accessed.
inherited
-
shouldRebuild(
covariant Component newComponent) → bool -
Implement this method to determine whether a rebuild can be skipped.
inherited
-
toString(
) → String -
A string representation of this object.
inherited
Operators
-
operator ==(
Object other) → bool -
The equality operator.
inherited