AuthSocialRow class
Row of social OAuth provider buttons.
Displays icon-only buttons in a horizontal row for social authentication providers (GitHub, Google, Apple).
- Inheritance
-
- Object
- Component
- StatelessComponent
- AuthSocialRow
Constructors
- AuthSocialRow({Key? key, required List methods, void onTap(dynamic)?, bool loading = false, bool disabled = false})
-
const
Properties
- disabled → bool
-
Whether the buttons are disabled
final
- hashCode → int
-
The hash code for this object.
no setterinherited
- key → Key?
-
Controls how one component replaces another component in the tree.
finalinherited
- loading → bool
-
Whether the buttons are loading
final
- methods → List
-
List of auth methods to display
final
- onTap → void Function(dynamic)?
-
Callback when a provider button is clicked
final
- runtimeType → Type
-
A representation of the runtime type of the object.
no setterinherited
Methods
-
build(
BuildContext context) → Component -
Describes the part of the user interface represented by this component.
override
-
createElement(
) → Element -
Creates a StatelessElement to manage this component's location in the tree.
inherited
-
noSuchMethod(
Invocation invocation) → dynamic -
Invoked when a nonexistent method or property is accessed.
inherited
-
shouldRebuild(
covariant Component newComponent) → bool -
Implement this method to determine whether a rebuild can be skipped.
inherited
-
toString(
) → String -
A string representation of this object.
inherited
Operators
-
operator ==(
Object other) → bool -
The equality operator.
inherited