AuthSplitLayout class
Split-screen layout for authentication pages.
Renders a two-column layout with branding content on the left and form content on the right. On mobile, only the form panel is shown with an optional header.
- Inheritance
-
- Object
- Component
- StatelessComponent
- AuthSplitLayout
Constructors
Properties
- brandingContent → Component
-
Content for the left branding panel
final
- formContent → Component
-
Content for the right form panel
final
- hashCode → int
-
The hash code for this object.
no setterinherited
- key → Key?
-
Controls how one component replaces another component in the tree.
finalinherited
- mobileHeader → Component?
-
Optional header shown on mobile (when branding panel is hidden)
final
- reverseSides → bool
-
Swap the left and right panels
final
- runtimeType → Type
-
A representation of the runtime type of the object.
no setterinherited
Methods
-
build(
BuildContext context) → Component -
Describes the part of the user interface represented by this component.
override
-
createElement(
) → Element -
Creates a StatelessElement to manage this component's location in the tree.
inherited
-
noSuchMethod(
Invocation invocation) → dynamic -
Invoked when a nonexistent method or property is accessed.
inherited
-
shouldRebuild(
covariant Component newComponent) → bool -
Implement this method to determine whether a rebuild can be skipped.
inherited
-
toString(
) → String -
A string representation of this object.
inherited
Operators
-
operator ==(
Object other) → bool -
The equality operator.
inherited