JasprAuthService class
Jaspr Authentication Service
Provides Firebase authentication for Jaspr web applications. Uses the Firebase JS SDK loaded in the HTML page.
Properties
-
authStateStream
→ Stream<
AuthState> -
Get the auth state stream
no setter
- currentState → AuthState
-
Get the current auth state
no setter
- currentUser → AuthUser?
-
Get the current user
no setter
- hashCode → int
-
The hash code for this object.
no setterinherited
- isAuthenticated → bool
-
Whether the user is authenticated
no setter
- runtimeType → Type
-
A representation of the runtime type of the object.
no setterinherited
Methods
-
deleteAccount(
) → Future< bool> - Delete account from server and sign out
-
dispose(
) → void - Dispose the service
-
initialize(
{String? serverApiUrl}) → void - Initialize the auth service
-
noSuchMethod(
Invocation invocation) → dynamic -
Invoked when a nonexistent method or property is accessed.
inherited
-
refreshToken(
) → Future< String?> - Refresh the ID token
-
registerWithEmail(
String email, String password, String displayName) → Future< void> - Register a new user with email and password
-
sendPasswordResetEmail(
String email) → Future< void> - Send password reset email
-
signInWithApple(
) → Future< void> - Sign in with Apple (placeholder - requires setup)
-
signInWithEmail(
String email, String password) → Future< void> - Sign in with email and password
-
signInWithGitHub(
) → Future< void> - Sign in with GitHub
-
signInWithGoogle(
) → Future< void> - Sign in with Google
-
signOut(
) → Future< void> - Sign out
-
toString(
) → String -
A string representation of this object.
inherited
Operators
-
operator ==(
Object other) → bool -
The equality operator.
inherited
Static Properties
- instance → JasprAuthService
-
Get the singleton instance
no setter