AuthUser class
Represents an authenticated user
Constructors
Properties
- displayName → String?
-
User's display name
final
- email → String?
-
User's email address
final
- emailVerified → bool
-
Whether the email is verified
final
- hashCode → int
-
The hash code for this object.
no setterinherited
- idToken → String?
-
Firebase ID token for server API calls
final
- isAnonymous → bool
-
Whether the user is anonymous
final
- photoURL → String?
-
User's photo URL
final
- runtimeType → Type
-
A representation of the runtime type of the object.
no setterinherited
- uid → String
-
Firebase UID
final
Methods
-
copyWith(
{String? uid, String? email, String? displayName, String? photoURL, String? idToken, bool? isAnonymous, bool? emailVerified}) → AuthUser - Create a copy with updated fields
-
noSuchMethod(
Invocation invocation) → dynamic -
Invoked when a nonexistent method or property is accessed.
inherited
-
toString(
) → String -
A string representation of this object.
override
Operators
-
operator ==(
Object other) → bool -
The equality operator.
inherited